#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
# wheeldir of name build does not work well with this packagename gh#openSUSE/python-rpm-macros#157
%define _pyproject_wheeldir distwheel

%{?sle15_python_module_pythons}
Name:           python-build%{psuffix}
Version:        0.10.0
Release:        3.3
Summary:        Simple PEP517 package builder
License:        MIT
URL:            https://github.com/pypa/build
Source0:        https://github.com/pypa/build/archive/%{version}.tar.gz#/build-%{version}.tar.gz
# Needs the wheels for wheel, flit-core, pytoml, and tomli for testing
Source10:       https://files.pythonhosted.org/packages/py2.py3/w/wheel/wheel-0.37.1-py2.py3-none-any.whl
Source11:       https://files.pythonhosted.org/packages/py3/f/flit-core/flit_core-3.8.0-py3-none-any.whl
Source12:       https://files.pythonhosted.org/packages/py3/t/tomli/tomli-2.0.1-py3-none-any.whl
# PATCH-FIX-UPSTREAM 589-colorized-pip23.patch gh#pypa/build#587 mcepl@suse.com
# Different style of colouring in pip 23 (actually I see it even with pip 22)
Patch0:         589-colorized-pip23.patch
# PATCH-FIX-UPSTREAM 609-filter-out-malicious.patch gh#pypa/build!609 mcepl@suse.com
# With new tarfile filters, there is now new warning
Patch1:         609-filter-out-malicious.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core >= 3.4}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-packaging >= 0.19.0
Requires:       python-pyproject-hooks
Requires:       (python-importlib-metadata >= 0.22 if python-base < 3.8)
Requires:       (python-tomli >= 1.1.0 if python-base < 3.11)
Recommends:     python-virtualenv >= 20.0.35
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module build = %{version}}
BuildRequires:  %{python_module filelock >= 3}
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  %{python_module pytest-mock >= 2}
BuildRequires:  %{python_module pytest-rerunfailures >= 9.1}
BuildRequires:  %{python_module pytest-xdist >= 1.34}
BuildRequires:  %{python_module setuptools >= 42 if %python-base < 3.10}
BuildRequires:  %{python_module setuptools >= 56 if %python-base >= 3.11}
BuildRequires:  %{python_module toml >= 0.10.0}
BuildRequires:  %{python_module wheel >= 0.36}
BuildRequires:  python3-setuptools-wheel
%endif
%python_subpackages

%description
Build will invoke the PEP 517 hooks to build a distribution package.
It is a simple build tool and does not perform any dependency management.

%prep
%autosetup -p1 -n build-%{version}
# until we have gh#pypa/build#609
sed -i '/"error",/ a \  "ignore::DeprecationWarning:tarfile",' pyproject.toml

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyproject-build
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
mkdir -p wheels
cp %{SOURCE10} %{SOURCE11} %{SOURCE12} wheels/
export PIP_FIND_LINKS="%{python3_sitelib}/../wheels $PWD/wheels"
pushd tests
%pytest -n auto
popd
%endif

%if !%{with test}
%post
%python_install_alternative pyproject-build

%postun
%python_uninstall_alternative pyproject-build

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pyproject-build
%{python_sitelib}/build
%{python_sitelib}/build-%{version}.dist-info
%endif

%changelog
* Sat May  6 2023 Matej Cepl <mcepl@suse.com>
- Renamed patches support-pip-23.patch and
  support-tarfile-data-filter.patch to 589-colorized-pip23.patch
  and 609-filter-out-malicious.patch, respectively.
* Tue May  2 2023 Ben Greiner <code@bnavigator.de>
- Remove support-tarfile-data-filter.patch: better documentation
  required, preferable supported through upstream
  * gh#pypa/build#609
  * ignore the DeprecationWarning instead
* Tue May  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-pip-23.patch:
  * pip 23 also colorizes output, confusing the test.
- Add patch support-tarfile-data-filter.patch:
  * Set tarfile.data_filter if available.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Mar 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.10.0
  * Replace pep517 dependency with pyproject_hooks, into which
    pep517 has been renamed (PR #539, Fixes #529)
  * Change build backend from setuptools to flit (PR #470, Fixes
    [#394])
  * Dropped support for Python 3.6 (PR #532)
- Avoid namespace clashes with build/ directory
  * gh#openSUSE/python-rpm-macros#157
- Drop build-pr550-packaging22.patch
* Sun Jan  1 2023 Ben Greiner <code@bnavigator.de>
- Add build-pr550-packaging22.patch
  * gh#pypa/build#550: tests: fix for PEP 685 in packaging 22
- Be more specific in requirements
* Mon Nov  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.9.0
  * Hide a Python 3.11.0 unavoidable warning with venv (PR #527)
  * Fix infinite recursion error in check_dependency with circular dependencies (PR #512, Fixes #511)
  * Only import colorama on Windows (PR #494, Fixes #493)
  * Flush output more often to reduce interleaved output (PR #494)
  * Small API cleanup, like better __all__ and srcdir being read only. (PR #477)
  * Only use importlib_metadata when needed (PR #401)
  * Clarify in printout when build dependencies are being installed (PR #514)
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Update to v0.8.0
  * Accept `os.PathLike[str]` in addition to `str` for paths in
    public API (PR #392, Fixes #372)
  * Add schema validation for `build-system` table to check
    conformity with PEP 517 and PEP 518 (PR #365, Fixes #364)
  * Better support for Python 3.11 (sysconfig schemes PR #434, PR
    [#463], tomllib PR #443, warnings PR #420)
  * Improved error printouts (PR #442)
  * Avoid importing packaging unless needed (PR #395, Fixes #393)
  * Failure to create a virtual environment in the `build.env`
    module now raises `build.FailedProcessError` (PR #442)
- Rework test suite: provide wheels for testing
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.7.0
  Full changelog at
  https://pypa-build.readthedocs.io/en/stable/changelog.html
  * Dropped support for Python 2 and 3.5
- Avoid possible bootstrap build depcycles with _multibuild
- Drop remove-unused-import.patch
* Thu Dec 17 2020 Benjamin Greiner <code@bnavigator.de>
- Add remove-unused-import.patch to work with importlib_metadata
* Fri Nov 13 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.1.0
* Tue Sep 29 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.0.4
